@@ -1,9 +1,14 @@
-from Acquisition import aq_inner#, aq_parent
+from Acquisition import aq_inner
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.CMFCore.utils import getToolByName
-#from Products.statusmessages.interfaces import IStatusMessage
-#from Products.PFGVerkkomaksut import PFGVerkkomaksutMessageFactory as _
+
+#class PFGVerkkomaksutView(BrowserView):
+
+#    template = ViewPageTemplateFile('templates/verkkomaksut.pt')
+
+#    def __call__(self):
+#        return self.template()
 
 class PFGVerkkomaksutSuccessView(BrowserView):
 
