@@ -3,7 +3,10 @@
 __author__  = 'Taito Horiuchi <taito.horiuchi@abita.fi>'
 __docformat__ = 'plaintext'
 
-import md5
+try:
+    import hashlib
+except ImportError:
+    import md5
 import re
 from email import Encoders
 from email.MIMEMultipart import MIMEMultipart
@@ -12,7 +15,7 @@ from email.MIMEAudio import MIMEAudio
 from email.MIMEBase import MIMEBase
 from email.MIMEImage import MIMEImage
 from Acquisition import aq_chain, aq_inner,aq_parent
-
+from zope.interface import implements
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.utils import safe_unicode
 from Products.Archetypes.public import (
@@ -20,12 +23,14 @@ from Products.Archetypes.public import (
     Schema,
 )
 from Products.CMFCore.permissions import ModifyPortalContent
-from Products.ATContentTypes.content.base import registerATCT
+#from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.folder import ATFolderSchema, ATFolder
 
 from Products.ATContentTypes.content.document import finalizeATCTSchema
 
 from Products.PloneFormGen.content.actionAdapter import (
+    ATFieldProperty,
+    registerType,
     AnnotationStorage,
     BooleanField,
     IntegerField,
@@ -39,12 +44,11 @@ from Products.PloneFormGen.content.actionAdapter import (
     StringWidget,
 )
 from Products.PloneFormGen.content.formMailerAdapter import formMailerAdapterSchema, FormMailerAdapter
-from Products.PloneFormGen import HAS_PLONE25, HAS_PLONE30
 from Products.PloneFormGen.content.fieldsBase import BaseFormField
 from Products.PloneFormGen.content.thanksPage import FormThanksPage, ThanksPageSchema
-
 from Products.PFGVerkkomaksut import PFGVerkkomaksutMessageFactory as _
 from Products.PFGVerkkomaksut.config import PROJECTNAME
+from Products.PFGVerkkomaksut.interfaces import IPFGVerkkomaksut
 
 def check_float(value):
     try:
@@ -171,24 +175,6 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         default_method='field_ids',
     ),
 
-#    TextField(
-#        name='thanks_text',
-#        schemata='verkkomaksut',
-#        required=False,
-#        searchable=False,
-#        storage = AnnotationStorage(),
-#        primary=True,
-#        validators = ('isTidyHtmlWithCleanup',),
-#        default_output_type = 'text/x-html-safe',
-##        widget = TextAreaWidget(
-#        widget = RichWidget(
-#            label = _(u'Thanks Text'),
-#            description=_(u'This thanks text will be displayed when payment is successful.'),
-#            rows = 25,
-#            allow_file_upload = zconf.ATDocument.allow_document_upload,
-#              ),
-#    ),
-
     StringField(
         name='cancel_message',
         schemata='verkkomaksut',
@@ -223,14 +209,17 @@ finalizeATCTSchema(PFGVerkkomaksutSchema, folderish=True, moveDiscussion=False)
 class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
     """Verkkomaksut Payment Adapter"""
 
-    # Standard content type setup
-    portal_type = meta_type = 'PFGVerkkomaksut'
-    archetype_name = 'Verkkomaksut Payment Adapter'
+    portal_type = 'PFGVerkkomaksut'
     schema = PFGVerkkomaksutSchema
-    content_icon = 'mailaction.gif'
-    default_view = immediate_view = 'base_view'
     _at_rename_after_creation = True
-    __implements__ = (ATFolder.__implements__, )
+#    __implements__ = (ATFolder.__implements__, )
+    implements(IPFGVerkkomaksut)
+
+    next_order_number = ATFieldProperty('next_order_number')
+    merchant_id = ATFieldProperty('merchant_id')
+    price_field = ATFieldProperty('price_field')
+    merchant_authentication_code = ATFieldProperty('merchant_authentication_code')
+    cancel_message = ATFieldProperty('cancel_message')
 
     def canSetDefaultPage(self):
         return False
@@ -278,7 +267,11 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         sdm = getToolByName(self, 'session_data_manager')
         session = sdm.getSessionData(create=True)
 
-        m = md5.new()
+#        m = md5.new()
+        try:
+            m = hashlib.md5()
+        except:
+            m = md5.new()
         m.update(self.getMerchant_authentication_code())
         ## For TYPE S1
         m.update('|' + MERCHANT_ID)
@@ -417,10 +410,11 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
             path=dict(query=path, depth=1),
         )
         for brain in brains:
-            if HAS_PLONE25 and not HAS_PLONE30:
-                dl.add(brain.getObject().UID(), brain.Title)
-            if HAS_PLONE30:
-                dl.add(brain.UID, brain.Title)
+#            if HAS_PLONE25 and not HAS_PLONE30:
+#                dl.add(brain.getObject().UID(), brain.Title)
+#            if HAS_PLONE30:
+#                dl.add(brain.UID, brain.Title)
+            dl.add(brain.UID, brain.Title)
         return dl
 
     def price_fields(self):
@@ -459,4 +453,5 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         ids = [obj.id for obj in folder.contentValues() if isinstance(obj, BaseFormField)]
         return ids
 
-registerATCT(PFGVerkkomaksut, PROJECTNAME)
+#registerATCT(PFGVerkkomaksut, PROJECTNAME)
+registerType(PFGVerkkomaksut, PROJECTNAME)
