@@ -1,4 +1,7 @@
-from Products.Five import zcml
+try:
+    from Zope2.App import zcml
+except ImportError:
+    from Products.Five import zcml
 from Products.Five import fiveconfigure
 from Testing import ZopeTestCase as ztc
 from Products.PloneTestCase import PloneTestCase as ptc
@@ -18,10 +21,14 @@ def setup_pfg_verkkomaksut():
 
 #    ztc.installPackage('Products.PloneFormGen')
 #    ztc.installPackage('Products.PFGVerrkkomaksut')
-    ztc.installProduct('PloneFormGen')
+#    ztc.installProduct('PloneFormGen')
     ztc.installProduct('PFGVerkkomaksut')
 
+ztc.installProduct('PloneFormGen')
+#ztc.installProduct('PFGVerkkomaksut')
+
 setup_pfg_verkkomaksut()
+#ptc.setupPloneSite(products=['PloneFormGen'])
 ptc.setupPloneSite(products=['PloneFormGen', 'PFGVerkkomaksut'])
 class PFGVerkkomaksutTestCase(ptc.PloneTestCase):
     """We use this base class for all the tests in this package.
